api.authentication.v1.signature package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.signature package

## Submodules

## api.authentication.v1.signature.signature_authenticate module

Autogenerated API

`api.authentication.v1.signature.signature_authenticate.` `authenticate`(userName: str = None, domain: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user session based on a cryptographic signature (INTERNAL) Requires SIGNATURE authentication to be enabled on the server, and for the user. The signature authentication requires a serialized SignedMessage object with a valid signature using the authenticating users private key.

  Return type: | `dict`

## Module contents